@@ -3,16 +3,14 @@ import json
 import subprocess
 import sys
 
-from isc_common import getAttr
-
 
 def makeInfo():
     data = json.loads(io.open('./package.json', encoding='utf-8').read())
 
     info = []
     info.append(dict(libName='Разработка :', libVersion='"АО ИВЦ \"Информ\" (info@ivc-inform.ru)'))
-    info.append(dict(libName='Версия :', libVersion=getAttr(data, 'version')))
-    info.append(dict(libName='Авторы :', libVersion=getAttr(data, 'author')))
+    info.append(dict(libName='Версия :', libVersion=data.get('version')))
+    info.append(dict(libName='Авторы :', libVersion=data.get('author')))
     info.append(dict(libName='Контакты :', libVersion="+7 (495) 997-91-75"))
 
     installed_packages = subprocess.check_output([sys.executable, '-m', 'pip', 'freeze'])
