@@ -2,7 +2,7 @@ import logging
 
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr
+from isc_common import setAttr, delAttr, dictinct_list
 from isc_common.auth.managers.base_user_manager import BaseUserManager
 from isc_common.auth.models.usergroup import UserGroup
 from isc_common.bit import IsBitOn
@@ -71,7 +71,7 @@ class UserManager(BaseUserManager):
             _oldValues = oldValues
 
         data = self._remove_prop_(data)
-        values = [item for item in list(set(_oldValues) - set(data)) if not item.startswith('_')]
+        values = [item for item in dictinct_list(_oldValues) - set(data) if not item.startswith('_')]
         for item in values:
             setAttr(data, item, None)
 
