@@ -24,7 +24,6 @@ class AbstractUser(AbstractBaseUser, AuditModel):
     middle_name = NameField(verbose_name=_('отчетво'))
     usergroup = ManyToManyField(UserGroup, verbose_name=_('группы'))
 
-
     @property
     def is_admin(self):
         res = False
@@ -59,14 +58,20 @@ class AbstractUser(AbstractBaseUser, AuditModel):
     @property
     def get_full_name(self):
         return f'{self.last_name.strip() if self.last_name else self.username} ' \
-            f'{self.first_name.strip() if self.first_name else ""} ' \
-            f'{self.middle_name.strip() if self.middle_name else ""}'
+               f'{self.first_name.strip() if self.first_name else ""} ' \
+               f'{self.middle_name.strip() if self.middle_name else ""}'
 
     @property
     def get_short_name(self):
-        res = f'{self.last_name.strip() if self.last_name else self.username} ' \
-            f'{self.first_name.strip()[0:1].upper() if self.first_name else ""} ' \
-            f'{self.middle_name.strip()[0:1].upper() if self.middle_name else ""}'
+        fn = f'{self.first_name.strip()[0:1].upper() if self.first_name else ""}'
+        if fn != '':
+            fn = ' ' + fn + '.'
+
+        mn = f'{self.middle_name.strip()[0:1].upper() if self.middle_name else ""}'
+        if mn != '':
+            mn = ' ' + mn + '.'
+
+        res = f'{self.last_name.strip() if self.last_name else self.username}{fn}{mn}'
         if res.strip() == "":
             res = self.username
         return res.strip()
