@@ -4,13 +4,25 @@ from os import walk
 from pathlib import Path
 from shutil import copyfile
 
+
+def git_push(dest_path):
+    os.system(f'cd {dest_path} && git pull && git add . && git commit -am"." && git push')
+
+
+def file_append(size, sized, full_path_source, max_size, files, dir_path_dest, full_path_dest):
+    if sized + size > max_size:
+        if sized > 0:
+            return False
+    files.append((full_path_source, dir_path_dest, full_path_dest, size))
+    sized += size
+    print(f'file append ({round(sized / max_size * 1024, 2)} MB) : {full_path_dest}')
+    return True, sized
+
+
 def do(argv):
     # print(argv)
     # print(os.path.abspath(os.curdir))
 
-    def git_psh(dest_path):
-        os.system(f'cd {dest_path} && git pull && git add . && git commit -am"." && git push')
-
     max_size = 1024 * 1024 * 1024
 
     if len(argv) < 2 or not os.path.isdir(argv[1]):
@@ -24,6 +36,9 @@ def do(argv):
     excl = ['.git', '.idea']
 
     files = []
+    sized = 0
+    apend_res = False
+
     for (dirpath, dirnames, filenames) in walk(source_path):
         for filename in filenames:
             full_path_source = f'{dirpath}{os.sep}{filename}'
@@ -35,20 +50,33 @@ def do(argv):
             full_path_dest = full_path_source.replace(source_path, dest_path)
             dir_path_dest = dirpath.replace(source_path, dest_path)
             if not os.path.exists(full_path_dest):
-                files.append((full_path_source, dir_path_dest, full_path_dest, stat_source.st_size))
+                apend_res, sized = file_append(
+                    dir_path_dest=dir_path_dest,
+                    files=files,
+                    full_path_dest=full_path_dest,
+                    full_path_source=full_path_source,
+                    max_size=max_size,
+                    sized=sized,
+                    size=stat_source.st_size,
+                )
             else:
                 stat_dest = Path(full_path_dest).stat()
-                # if stat_source.st_size != stat_dest.st_size or stat_source.st_mtime != stat_dest.st_mtime:
                 if stat_source.st_size != stat_dest.st_size:
-                    files.append((full_path_source, dir_path_dest, full_path_dest, stat_source.st_size))
+                    apend_res, sized = file_append(
+                        dir_path_dest=dir_path_dest,
+                        files=files,
+                        full_path_dest=full_path_dest,
+                        full_path_source=full_path_source,
+                        max_size=max_size,
+                        sized=sized,
+                        size=stat_source.st_size,
+                    )
+                else:
+                    apend_res = True
+            if apend_res is False:
+                break
 
-    sized = 0
     for src, dir_dst, dst, size in files:
-        if sized + size > max_size:
-            if sized > 0:
-                git_psh(dest_path=dest_path)
-            return False
-
         if not os.path.exists(dir_dst):
             os.makedirs(dir_dst)
 
@@ -57,9 +85,9 @@ def do(argv):
         sized += size
 
     if sized > 0:
-        git_psh(dest_path=dest_path)
+        git_push(dest_path=dest_path)
 
-    return True
+    return apend_res
 
 
 if __name__ == '__main__':
