@@ -1,6 +1,7 @@
 import os
 import urllib.request
 
+from django.conf import settings
 from django.http import HttpResponse
 
 from kaf_pas.common.UploadItem import UploadItem
@@ -9,7 +10,16 @@ from tracker.models.messages_files import Messages_files
 
 def message_download_file(request, id):
     obj = Messages_files.objects.get(id=id)
-    item = UploadItem(stored_file_name=os.path.basename(obj.attfile.path), key=obj.key)
+    if os.path.exists(obj.attfile.name):
+        path = obj.attfile.path
+    else:
+        path = obj.attfile.name
+        file_name = path.split(os.sep)[-1]
+        path = f'{settings.FILES_STORE}{os.sep}{file_name}'
+        if not os.path.exists(path):
+            raise Exception(f'Path: {path} not exists.')
+
+    item = UploadItem(stored_file_name=os.path.basename(path), key=obj.key)
     if obj.key:
         path_decrypt = item.decrypt()
     else:
